Requirements
============
CherryPy_

.. _CherryPy: http://www.cherrypy.org/

Installation
============

1. Put ``django_cpserver`` on your ``PYTHONPATH``.
2. Add ``django_cpserver`` to your ``INSTALLED_APPS``.

Usage
=====

Run ``./manage.py runcpserver help`` from within your project directory

Acknowledgements
================

Idea and code snippets borrowed from `Loic d'Anterroches`__, adapted to run as a management command

__ http://www.xhtml.net/scripts/Django-CherryPy-server-DjangoCerise

Modifications
=============

This version is mantained by Manuel Naranjo < manuel at aircable dot net > mail
him for modifications questions.
